@@ -13,6 +13,10 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 #
+from google.cloud.documentai import gapic_version as package_version
+
+__version__ = package_version.__version__
+
 
 from .services.document_processor_service import (
     DocumentProcessorServiceAsyncClient,
@@ -49,6 +53,7 @@ from .types.document_processor_service import (
     FetchProcessorTypesRequest,
     FetchProcessorTypesResponse,
     GetProcessorRequest,
+    GetProcessorTypeRequest,
     GetProcessorVersionRequest,
     HumanReviewStatus,
     ListProcessorsRequest,
@@ -108,6 +113,7 @@ __all__ = (
     "GcsDocuments",
     "GcsPrefix",
     "GetProcessorRequest",
+    "GetProcessorTypeRequest",
     "GetProcessorVersionRequest",
     "HumanReviewStatus",
     "ListProcessorTypesRequest",
