@@ -58,6 +58,7 @@ from .types.document_processor_service import (
     FetchProcessorTypesResponse,
     GetEvaluationRequest,
     GetProcessorRequest,
+    GetProcessorTypeRequest,
     GetProcessorVersionRequest,
     HumanReviewStatus,
     ListEvaluationsRequest,
@@ -129,6 +130,7 @@ __all__ = (
     "GcsPrefix",
     "GetEvaluationRequest",
     "GetProcessorRequest",
+    "GetProcessorTypeRequest",
     "GetProcessorVersionRequest",
     "HumanReviewStatus",
     "ListEvaluationsRequest",
