@@ -27,6 +27,7 @@ __protobuf__ = proto.module(
         "GcsPrefix",
         "BatchDocumentsInputConfig",
         "DocumentOutputConfig",
+        "OcrConfig",
     },
 )
 
@@ -218,4 +219,20 @@ class DocumentOutputConfig(proto.Message):
     )
 
 
+class OcrConfig(proto.Message):
+    r"""Config for Document OCR.
+
+    Attributes:
+        enable_native_pdf_parsing (bool):
+            Enables special handling for PDFs with
+            existing text information. Results in better
+            text extraction quality in such PDF inputs.
+    """
+
+    enable_native_pdf_parsing: bool = proto.Field(
+        proto.BOOL,
+        number=3,
+    )
+
+
 __all__ = tuple(sorted(__protobuf__.manifest))
